@@ -7,6 +7,6 @@ module.exports = {
   },
   testEnvironment: 'jsdom',
   transform: {
-    '^.+.tsx?$': '<rootDir>/../../dist/index.js',
+    '^.+.tsx?$': '<rootDir>/../../legacy.js',
   },
 }
